@@ -130,12 +130,15 @@ def rm(obj, name):
 @click.option('--parallel', help='start jobs in parallel', is_flag=True)
 @click.option('--jobs', '-j', help='start N jobs in parallel',
               default=None, type=int, metavar='N')
-@click.option('--force', '-f', is_flag=True, help='do not check cache')
+@click.option('--force', '-f', is_flag=True, help='force plugin execution even if entry was already seen')
 @click.option('--catchup', '-n',
               is_flag=True, help='tell output plugins to do nothing permanent')
-def fetch(obj, pattern, parallel, jobs, force, catchup):
+@click.option('--nocache', is_flag=True, help='do not use the HTTP cache')
+def fetch(obj, pattern, parallel, jobs, force, catchup, nocache):
     feed_manager = obj['feed_manager']
     feed_manager.pattern = pattern
+    if nocache:
+        feed_manager.sessionConfig(cache=False)
     parallel = jobs or parallel
     feed_manager.fetch(parallel, force=force, catchup=catchup)
 
