@@ -39,6 +39,7 @@ from feed2exec.model import Feed, FeedConfStorage, FeedContentCacheStorage, Feed
 import feedparser
 from pkg_resources import parse_version
 import requests
+from requests.adapters import HTTPAdapter
 import requests_file
 try:
     import cachecontrol
@@ -88,7 +89,7 @@ class FeedManager(object):
     def __repr__(self):
         return 'FeedManager(%s, %s, %s)' % (self.conf_path, self.db_path, self.pattern)
 
-    def sessionConfig(self):
+    def sessionConfig(self, cache=True):
         """our custom session configuration
 
         we change the user agent and set the file:// hanlder. extra
@@ -97,31 +98,40 @@ class FeedManager(object):
 
         this can be used to configure sessions used externally, for
         example by plugins.
+
+        This can also be used to disable the cache.
         """
         self._session.headers.update({'User-Agent': '%s/%s'
                                       % (feed2exec.__prog__,
                                          feed2exec.__version__)})
         self._session.mount('file://', requests_file.FileAdapter())
-        if self.db_path is not None and cachecontrol is not None:
-            cache_adapter = cachecontrol.CacheControlAdapter(cache=FeedContentCacheStorage(self.db_path))
-            # assume we mount over http and https all at once so check
-            # only the latter
-            adapter = self._session.adapters.get('https://', None)
-            if hasattr(adapter, 'old_adapters'):
-                # looks like a betamax session was setup, hook ourselves behind it
-                #
-                # XXX: this doesn't actually work, as betamax will
-                # never pass the query to the cache. this is
-                # backwards, but there's no other way. see
-                # https://github.com/ionrock/cachecontrol/issues/212
-                logging.debug('appending cache adapter (%r) to existing betamax adapter (%r)', cache_adapter, adapter)
-                adapter.old_adapters['http://'] = cache_adapter
-                adapter.old_adapters['https://'] = cache_adapter
-            else:
-                logging.debug('mounting cache adapter (%r)', cache_adapter)
-                # override existing adapters to use the cache adapter instead
-                self._session.mount('http://', cache_adapter)
-                self._session.mount('https://', cache_adapter)
+        if self.db_path is None or cachecontrol is None:
+            return
+        if not cache:
+            # reset the session adapters to *not* use an eventual cache controller
+            # from requests.Session.__init__()
+            self._session.mount("https://", HTTPAdapter())
+            self._session.mount("http://", HTTPAdapter())
+            return
+        cache_adapter = cachecontrol.CacheControlAdapter(cache=FeedContentCacheStorage(self.db_path))
+        # assume we mount over http and https all at once so check
+        # only the latter
+        adapter = self._session.adapters.get('https://', None)
+        if hasattr(adapter, 'old_adapters'):
+            # looks like a betamax session was setup, hook ourselves behind it
+            #
+            # XXX: this doesn't actually work, as betamax will
+            # never pass the query to the cache. this is
+            # backwards, but there's no other way. see
+            # https://github.com/ionrock/cachecontrol/issues/212
+            logging.debug('appending cache adapter (%r) to existing betamax adapter (%r)', cache_adapter, adapter)
+            adapter.old_adapters['http://'] = cache_adapter
+            adapter.old_adapters['https://'] = cache_adapter
+        else:
+            logging.debug('mounting cache adapter (%r)', cache_adapter)
+            # override existing adapters to use the cache adapter instead
+            self._session.mount('http://', cache_adapter)
+            self._session.mount('https://', cache_adapter)
 
     @property
     def session(self):
